.. _dependency:

Dependency
==========

StorLever is based on RHEL/CentOS 6 linux distribution, the perfect choice for enterprise class storage solution.
Following is a list of RHEL/CentOS 6 packages that needed by StorLever, some of them are optional.

* python: to run StorLever

* mdadm (optional): utilities for software raid management
* iscsi-initiator-utils (optional): iSCSI initiator utilities
* lvm2: logical volume utilities
* xfsprogs (optional): XFS filesystem
* xfsdump (optional): same as above
* e2fsprogs (optional): EXT3/4 filesystem
* nfs-utils (optional): for both NFS client and server
* samba (optional): for both SAMBA client and server
* tftp-server (optional): FTP server
* scsi-target-utils (optional): iSCSI target

* net-snmp: SNMP utilities
* ntp: for date time synchronization

StorLever supports RAID controllers with LSI SAS 2208/2108/2008 chip, to enable this feature, please
make sure following packages are installed:

* MegaRaid SAS driver: driver for RAID controller
* MegaCli: command line util to manager RAID controller

